<?php
/*
** Zabbix
** Copyright (C) 2000-2011 Zabbix SIA
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
**/
?>
<?php
require_once 'PHPUnit/Framework.php';

require_once dirname(__FILE__).'/../../../include/locales.inc.php';
require_once dirname(__FILE__).'/../../../include/gettextwrapper.inc.php';
require_once dirname(__FILE__).'/../../../include/defines.inc.php';
require_once dirname(__FILE__).'/../../../include/validate.inc.php';
require_once dirname(__FILE__).'/../../../include/func.inc.php';
require_once dirname(__FILE__).'/../../../include/items.inc.php';
require_once dirname(__FILE__).'/../../../include/triggers.inc.php';
require_once dirname(__FILE__).'/../../../api/classes/CTriggerExpression.php';
require_once dirname(__FILE__).'/../../../api/classes/CItemKey.php';

class class_triggerexpressionTest extends PHPUnit_Framework_TestCase {
	public static function provider() {
		return array(
	// Correct trigger expressions
			array('',false),
			array('+',false),
			array('1',false),
			array('1+1',false),
			array('abc',false),
			array('{TRIGGER.VALUE}',false),
			array('{$USERMACRO}',false),
			array('{TRIGGER.VALUE}=1',false),
			array('{$USERMACRO}=1',false),
			array('{host}',false),
			array('{host:key}',false),
			array('{host:key.str}',false),

			array('{host:key.diff()} & {TRIGGER.VALUE}',true),
			array('{host:key.diff()}& {TRIGGER.VALUE}',true),
			array('{host:key.diff()}  &{TRIGGER.VALUE}',true),
			array('{host:key.diff()}&{TRIGGER.VALUE}',true),
			array('{host:key.diff()}&+{TRIGGER.VALUE}',false),
			array('{host:key.diff()}&-{TRIGGER.VALUE}',true),
			array('{host:key.diff()} & + {TRIGGER.VALUE}',false),
			array('{host:key.diff()} & - {TRIGGER.VALUE}',true),

			array('{host:key.diff()} & {$USERMACRO}',true),
			array('{host:key.diff()}& {$USERMACRO}',true),
			array('{host:key.diff()} &{$USERMACRO}',true),
			array('{host:key.diff()}&{$USERMACRO}',true),
			array('{host:key.diff()} & + {$USERMACRO}',false),
			array('{host:key.diff()} & - {$USERMACRO}',true),

			array('{host:key.diff()}=00',true),
			array('{host:key.diff()}=0 0',false),
			array('{host:key.diff()}=0 0={host:key.diff()}',false),
			array('{host:key.diff()} = 00 = {host:key.diff()}',true),

			array('{host:key.str(ГУГЛ)}=0',true),
			array('{host:key.str("ГУГЛ")}=0',true),
			array('{host:key[ГУГЛ].str(ГУГЛ)}=0',true),
			array('{host:key["ГУГЛ"].str("ГУГЛ")}=0',true),
			array('{host:key.str("こんにちは、世界")}',true),
			array('{host:key.str(こんにちは、世界)}',true),
			array('{host:key["こんにちは、世界"].str("こんにちは、世界")}',true),
			array('{host:key[こんにちは、世界].str(こんにちは、世界)}',true),

			array('{host:key[a,,"b",,[c,d,,"e",],,[f]].count(1,,"b",3)}',true),
			array('{host:key[a,,"b",,[[c,d,,"e"],[]],,[f]].count(1,,"b",3)}',true),
			array('{host:key[a,,"b",,[c,d,,"e",,,[f]].count(1,,"b",3)}',false),
			array('{host:key[a,,"b",,[c,d,,"e",],,f]].count(1,,"b",3)}',false),

			array('{abcdefghijklmnopqrstuvwxyz. _-ABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890:key.diff()}',true),
			array('{host:abcdefghijklmnopqrstuvwxyz._-ABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890.diff()}',true),
			array('{host:,.diff()}',false),
			array('{host:;.diff()}',false),
			array('{host::.diff()}',false),
			array('{host:.diff()}',false),
			array('{:key.diff()}',false),
			array('{host:key.()}',false),

			array(' {host:key.diff()} ',true),
			array('({host:key.diff()})',true),
			array('{(host:key.diff()})',false),
			array('({host:key.diff())}',false),
			array('{(host:key.diff())}',false),
			array('{(host:key.diff()})=0',false),
			array('({host:key.diff())}=0',false),
			array('{(host:key.diff())}=0',false),
			array('({host:key.diff()}=)0',false),
			array('({host:key.diff()})0',false),
			array('0(={host:key.diff()})',false),
			array('0({host:key.diff()})',false),
			array('( {host:key.diff()} )',true),
			array(' ( {host:key.diff()} ) ',true),
			array('(( {host:key.diff()} ))',true),
			array(' ( ( {host:key.diff()} ) ) ',true),
			array('((( {host:key.diff()} )))',true),
			array(' ( ( ( {host:key.diff()} ) ) ) ',true),
			array('()0={host:key.diff()}',false),
			array('0()={host:key.diff()}',false),
			array('0=()={host:key.diff()}',false),
			array('0=(){host:key.diff()}',false),
			array('0={()host:key.diff()}',false),
			array('0={host:key.diff()()}',false),
			array('0={host:key.diff()}()',false),
			array('0={host:key.diff()}+()()()()5',false),
			array('0={host:key.diff()}+((((()))))5',false),
			array('(0)={host:key.diff()}',true),
			array('(0+)={host:key.diff()}',false),
			array('(0=){host:key.diff()}',false),
			array('({host:key.diff)()}',false),
			array('({host:key.)diff()}',false),
			array('({host:key).diff()}',false),
			array('(-5)={host:key.diff()}',true),
			array('(15 - 5.25 - 1)={host:key.diff()}',true),
			array('{host:key.diff()} = -5',true),

			array('(({host:key.diff()})=0)',true),
			array('( ( {host:key.diff()} ) = 0 )',true),
			array('(({host:key.diff()}) * 100) / 95',true),
			array('(({host:key.diff()}) * 5.25K) / 95.0',true),
			array('(({host:key.diff()}) * 1w) / 1d',true),
			array('(({host:key.diff()}) * 1w) / 1Ks',false),
			array('(({host:key.diff()}) * 1w) / (1d * ({host:key.diff()})',false),
			array('(({host:key.diff()}) * 1w) / (1d * host:key.diff()}))',false),
			array('(({host:key.diff()}) * 1w) / (1d * ({host:key.diff()}))',true),

			array('{host:key.last(1)} * (-1)',true),
			array('{host:key.last(1)} / (-1)',true),
			array('{host:key.last(1)} + (-1)',true),
			array('{host:key.last(1)} - (-1)',true),
			array('{host:key.last(1)} = (-1)',true),
			array('{host:key.last(1)} # (-1)',true),
			array('{host:key.last(1)} < (-1)',true),
			array('{host:key.last(1)} > (-1)',true),
			array('{host:key.last(1)} & (-1)',true),
			array('{host:key.last(1)} | (-1)',true),

			array('{host:key.last(1)}* (-1)',true),
			array('{host:key.last(1)}/ (-1)',true),
			array('{host:key.last(1)}+ (-1)',true),
			array('{host:key.last(1)}- (-1)',true),
			array('{host:key.last(1)}= (-1)',true),
			array('{host:key.last(1)}# (-1)',true),
			array('{host:key.last(1)}< (-1)',true),
			array('{host:key.last(1)}> (-1)',true),
			array('{host:key.last(1)}& (-1)',true),
			array('{host:key.last(1)}| (-1)',true),

			array('{host:key.last(1)} *(-1)',true),
			array('{host:key.last(1)} /(-1)',true),
			array('{host:key.last(1)} +(-1)',true),
			array('{host:key.last(1)} -(-1)',true),
			array('{host:key.last(1)} =(-1)',true),
			array('{host:key.last(1)} #(-1)',true),
			array('{host:key.last(1)} <(-1)',true),
			array('{host:key.last(1)} >(-1)',true),
			array('{host:key.last(1)} &(-1)',true),
			array('{host:key.last(1)} |(-1)',true),

			array('{host:key.last(1)}*(-1)',true),
			array('{host:key.last(1)}/(-1)',true),
			array('{host:key.last(1)}+(-1)',true),
			array('{host:key.last(1)}-(-1)',true),
			array('{host:key.last(1)}=(-1)',true),
			array('{host:key.last(1)}#(-1)',true),
			array('{host:key.last(1)}<(-1)',true),
			array('{host:key.last(1)}>(-1)',true),
			array('{host:key.last(1)}&(-1)',true),
			array('{host:key.last(1)}|(-1)',true),

			array('{host:key.last(1)} * -1',true),
			array('{host:key.last(1)} / -1',true),
			array('{host:key.last(1)} + -1',true),
			array('{host:key.last(1)} - -1',true),
			array('{host:key.last(1)} = -1',true),
			array('{host:key.last(1)} # -1',true),
			array('{host:key.last(1)} < -1',true),
			array('{host:key.last(1)} > -1',true),
			array('{host:key.last(1)} & -1',true),
			array('{host:key.last(1)} | -1',true),

			array('{host:key.last(1)}* -1',true),
			array('{host:key.last(1)}/ -1',true),
			array('{host:key.last(1)}+ -1',true),
			array('{host:key.last(1)}- -1',true),
			array('{host:key.last(1)}= -1',true),
			array('{host:key.last(1)}# -1',true),
			array('{host:key.last(1)}< -1',true),
			array('{host:key.last(1)}> -1',true),
			array('{host:key.last(1)}& -1',true),
			array('{host:key.last(1)}| -1',true),

			array('{host:key.last(1)} *-1',true),
			array('{host:key.last(1)} /-1',true),
			array('{host:key.last(1)} +-1',true),
			array('{host:key.last(1)} --1',true),
			array('{host:key.last(1)} =-1',true),
			array('{host:key.last(1)} #-1',true),
			array('{host:key.last(1)} <-1',true),
			array('{host:key.last(1)} >-1',true),
			array('{host:key.last(1)} &-1',true),
			array('{host:key.last(1)} |-1',true),

			array('{host:key.last(1)}*-1',true),
			array('{host:key.last(1)}/-1',true),
			array('{host:key.last(1)}+-1',true),
			array('{host:key.last(1)}--1',true),
			array('{host:key.last(1)}=-1',true),
			array('{host:key.last(1)}#-1',true),
			array('{host:key.last(1)}<-1',true),
			array('{host:key.last(1)}>-1',true),
			array('{host:key.last(1)}&-1',true),
			array('{host:key.last(1)}|-1',true),

			array('{host:key.last(1)} * (- 1)',true),
			array('{host:key.last(1)} / (- 1)',true),
			array('{host:key.last(1)} + (- 1)',true),
			array('{host:key.last(1)} - (- 1)',true),
			array('{host:key.last(1)} = (- 1)',true),
			array('{host:key.last(1)} # (- 1)',true),
			array('{host:key.last(1)} < (- 1)',true),
			array('{host:key.last(1)} > (- 1)',true),
			array('{host:key.last(1)} & (- 1)',true),
			array('{host:key.last(1)} | (- 1)',true),

			array('{host:key.last(1)}* (- 1)',true),
			array('{host:key.last(1)}/ (- 1)',true),
			array('{host:key.last(1)}+ (- 1)',true),
			array('{host:key.last(1)}- (- 1)',true),
			array('{host:key.last(1)}= (- 1)',true),
			array('{host:key.last(1)}# (- 1)',true),
			array('{host:key.last(1)}< (- 1)',true),
			array('{host:key.last(1)}> (- 1)',true),
			array('{host:key.last(1)}& (- 1)',true),
			array('{host:key.last(1)}| (- 1)',true),

			array('{host:key.last(1)} *(- 1)',true),
			array('{host:key.last(1)} /(- 1)',true),
			array('{host:key.last(1)} +(- 1)',true),
			array('{host:key.last(1)} -(- 1)',true),
			array('{host:key.last(1)} =(- 1)',true),
			array('{host:key.last(1)} #(- 1)',true),
			array('{host:key.last(1)} <(- 1)',true),
			array('{host:key.last(1)} >(- 1)',true),
			array('{host:key.last(1)} &(- 1)',true),
			array('{host:key.last(1)} |(- 1)',true),

			array('{host:key.last(1)}*(- 1)',true),
			array('{host:key.last(1)}/(- 1)',true),
			array('{host:key.last(1)}+(- 1)',true),
			array('{host:key.last(1)}-(- 1)',true),
			array('{host:key.last(1)}=(- 1)',true),
			array('{host:key.last(1)}#(- 1)',true),
			array('{host:key.last(1)}<(- 1)',true),
			array('{host:key.last(1)}>(- 1)',true),
			array('{host:key.last(1)}&(- 1)',true),
			array('{host:key.last(1)}|(- 1)',true),

			array('{host:key.last(1)} * - 1',true),
			array('{host:key.last(1)} / - 1',true),
			array('{host:key.last(1)} + - 1',true),
			array('{host:key.last(1)} - - 1',true),
			array('{host:key.last(1)} = - 1',true),
			array('{host:key.last(1)} # - 1',true),
			array('{host:key.last(1)} < - 1',true),
			array('{host:key.last(1)} > - 1',true),
			array('{host:key.last(1)} & - 1',true),
			array('{host:key.last(1)} | - 1',true),

			array('{host:key.last(1)}* - 1',true),
			array('{host:key.last(1)}/ - 1',true),
			array('{host:key.last(1)}+ - 1',true),
			array('{host:key.last(1)}- - 1',true),
			array('{host:key.last(1)}= - 1',true),
			array('{host:key.last(1)}# - 1',true),
			array('{host:key.last(1)}< - 1',true),
			array('{host:key.last(1)}> - 1',true),
			array('{host:key.last(1)}& - 1',true),
			array('{host:key.last(1)}| - 1',true),

			array('{host:key.last(1)} *- 1',true),
			array('{host:key.last(1)} /- 1',true),
			array('{host:key.last(1)} +- 1',true),
			array('{host:key.last(1)} -- 1',true),
			array('{host:key.last(1)} =- 1',true),
			array('{host:key.last(1)} #- 1',true),
			array('{host:key.last(1)} <- 1',true),
			array('{host:key.last(1)} >- 1',true),
			array('{host:key.last(1)} &- 1',true),
			array('{host:key.last(1)} |- 1',true),

			array('{host:key.last(1)}*- 1',true),
			array('{host:key.last(1)}/- 1',true),
			array('{host:key.last(1)}+- 1',true),
			array('{host:key.last(1)}-- 1',true),
			array('{host:key.last(1)}=- 1',true),
			array('{host:key.last(1)}#- 1',true),
			array('{host:key.last(1)}<- 1',true),
			array('{host:key.last(1)}>- 1',true),
			array('{host:key.last(1)}&- 1',true),
			array('{host:key.last(1)}|- 1',true),

			array('{host:key.last(1)} * (+1)',false),
			array('{host:key.last(1)} / (+1)',false),
			array('{host:key.last(1)} + (+1)',false),
			array('{host:key.last(1)} - (+1)',false),
			array('{host:key.last(1)} = (+1)',false),
			array('{host:key.last(1)} # (+1)',false),
			array('{host:key.last(1)} < (+1)',false),
			array('{host:key.last(1)} > (+1)',false),
			array('{host:key.last(1)} & (+1)',false),
			array('{host:key.last(1)} | (+1)',false),

			array('{host:key.last(1)}* (+1)',false),
			array('{host:key.last(1)}/ (+1)',false),
			array('{host:key.last(1)}+ (+1)',false),
			array('{host:key.last(1)}- (+1)',false),
			array('{host:key.last(1)}= (+1)',false),
			array('{host:key.last(1)}# (+1)',false),
			array('{host:key.last(1)}< (+1)',false),
			array('{host:key.last(1)}> (+1)',false),
			array('{host:key.last(1)}& (+1)',false),
			array('{host:key.last(1)}| (+1)',false),

			array('{host:key.last(1)} *(+1)',false),
			array('{host:key.last(1)} /(+1)',false),
			array('{host:key.last(1)} +(+1)',false),
			array('{host:key.last(1)} -(+1)',false),
			array('{host:key.last(1)} =(+1)',false),
			array('{host:key.last(1)} #(+1)',false),
			array('{host:key.last(1)} <(+1)',false),
			array('{host:key.last(1)} >(+1)',false),
			array('{host:key.last(1)} &(+1)',false),
			array('{host:key.last(1)} |(+1)',false),

			array('{host:key.last(1)}*(+1)',false),
			array('{host:key.last(1)}/(+1)',false),
			array('{host:key.last(1)}+(+1)',false),
			array('{host:key.last(1)}-(+1)',false),
			array('{host:key.last(1)}=(+1)',false),
			array('{host:key.last(1)}#(+1)',false),
			array('{host:key.last(1)}<(+1)',false),
			array('{host:key.last(1)}>(+1)',false),
			array('{host:key.last(1)}&(+1)',false),
			array('{host:key.last(1)}|(+1)',false),

			array('{host:key.last(1)} * +1',false),
			array('{host:key.last(1)} / +1',false),
			array('{host:key.last(1)} + +1',false),
			array('{host:key.last(1)} - +1',false),
			array('{host:key.last(1)} = +1',false),
			array('{host:key.last(1)} # +1',false),
			array('{host:key.last(1)} < +1',false),
			array('{host:key.last(1)} > +1',false),
			array('{host:key.last(1)} & +1',false),
			array('{host:key.last(1)} | +1',false),

			array('{host:key.last(1)}* +1',false),
			array('{host:key.last(1)}/ +1',false),
			array('{host:key.last(1)}+ +1',false),
			array('{host:key.last(1)}- +1',false),
			array('{host:key.last(1)}= +1',false),
			array('{host:key.last(1)}# +1',false),
			array('{host:key.last(1)}< +1',false),
			array('{host:key.last(1)}> +1',false),
			array('{host:key.last(1)}& +1',false),
			array('{host:key.last(1)}| +1',false),

			array('{host:key.last(1)} *+1',false),
			array('{host:key.last(1)} /+1',false),
			array('{host:key.last(1)} ++1',false),
			array('{host:key.last(1)} -+1',false),
			array('{host:key.last(1)} =+1',false),
			array('{host:key.last(1)} #+1',false),
			array('{host:key.last(1)} <+1',false),
			array('{host:key.last(1)} >+1',false),
			array('{host:key.last(1)} &+1',false),
			array('{host:key.last(1)} |+1',false),

			array('{host:key.last(1)}*+1',false),
			array('{host:key.last(1)}/+1',false),
			array('{host:key.last(1)}++1',false),
			array('{host:key.last(1)}-+1',false),
			array('{host:key.last(1)}=+1',false),
			array('{host:key.last(1)}#+1',false),
			array('{host:key.last(1)}<+1',false),
			array('{host:key.last(1)}>+1',false),
			array('{host:key.last(1)}&+1',false),
			array('{host:key.last(1)}|+1',false),

			array('{host:key.last(1)} * (+ 1)',false),
			array('{host:key.last(1)} / (+ 1)',false),
			array('{host:key.last(1)} + (+ 1)',false),
			array('{host:key.last(1)} - (+ 1)',false),
			array('{host:key.last(1)} = (+ 1)',false),
			array('{host:key.last(1)} # (+ 1)',false),
			array('{host:key.last(1)} < (+ 1)',false),
			array('{host:key.last(1)} > (+ 1)',false),
			array('{host:key.last(1)} & (+ 1)',false),
			array('{host:key.last(1)} | (+ 1)',false),

			array('{host:key.last(1)}* (+ 1)',false),
			array('{host:key.last(1)}/ (+ 1)',false),
			array('{host:key.last(1)}+ (+ 1)',false),
			array('{host:key.last(1)}- (+ 1)',false),
			array('{host:key.last(1)}= (+ 1)',false),
			array('{host:key.last(1)}# (+ 1)',false),
			array('{host:key.last(1)}< (+ 1)',false),
			array('{host:key.last(1)}> (+ 1)',false),
			array('{host:key.last(1)}& (+ 1)',false),
			array('{host:key.last(1)}| (+ 1)',false),

			array('{host:key.last(1)} *(+ 1)',false),
			array('{host:key.last(1)} /(+ 1)',false),
			array('{host:key.last(1)} +(+ 1)',false),
			array('{host:key.last(1)} -(+ 1)',false),
			array('{host:key.last(1)} =(+ 1)',false),
			array('{host:key.last(1)} #(+ 1)',false),
			array('{host:key.last(1)} <(+ 1)',false),
			array('{host:key.last(1)} >(+ 1)',false),
			array('{host:key.last(1)} &(+ 1)',false),
			array('{host:key.last(1)} |(+ 1)',false),

			array('{host:key.last(1)}*(+ 1)',false),
			array('{host:key.last(1)}/(+ 1)',false),
			array('{host:key.last(1)}+(+ 1)',false),
			array('{host:key.last(1)}-(+ 1)',false),
			array('{host:key.last(1)}=(+ 1)',false),
			array('{host:key.last(1)}#(+ 1)',false),
			array('{host:key.last(1)}<(+ 1)',false),
			array('{host:key.last(1)}>(+ 1)',false),
			array('{host:key.last(1)}&(+ 1)',false),
			array('{host:key.last(1)}|(+ 1)',false),

			array('{host:key.last(1)} * + 1',false),
			array('{host:key.last(1)} / + 1',false),
			array('{host:key.last(1)} + + 1',false),
			array('{host:key.last(1)} - + 1',false),
			array('{host:key.last(1)} = + 1',false),
			array('{host:key.last(1)} # + 1',false),
			array('{host:key.last(1)} < + 1',false),
			array('{host:key.last(1)} > + 1',false),
			array('{host:key.last(1)} & + 1',false),
			array('{host:key.last(1)} | + 1',false),

			array('{host:key.last(1)}* + 1',false),
			array('{host:key.last(1)}/ + 1',false),
			array('{host:key.last(1)}+ + 1',false),
			array('{host:key.last(1)}- + 1',false),
			array('{host:key.last(1)}= + 1',false),
			array('{host:key.last(1)}# + 1',false),
			array('{host:key.last(1)}< + 1',false),
			array('{host:key.last(1)}> + 1',false),
			array('{host:key.last(1)}& + 1',false),
			array('{host:key.last(1)}| + 1',false),

			array('{host:key.last(1)} *+ 1',false),
			array('{host:key.last(1)} /+ 1',false),
			array('{host:key.last(1)} ++ 1',false),
			array('{host:key.last(1)} -+ 1',false),
			array('{host:key.last(1)} =+ 1',false),
			array('{host:key.last(1)} #+ 1',false),
			array('{host:key.last(1)} <+ 1',false),
			array('{host:key.last(1)} >+ 1',false),
			array('{host:key.last(1)} &+ 1',false),
			array('{host:key.last(1)} |+ 1',false),

			array('{host:key.last(1)}*+ 1',false),
			array('{host:key.last(1)}/+ 1',false),
			array('{host:key.last(1)}++ 1',false),
			array('{host:key.last(1)}-+ 1',false),
			array('{host:key.last(1)}=+ 1',false),
			array('{host:key.last(1)}#+ 1',false),
			array('{host:key.last(1)}<+ 1',false),
			array('{host:key.last(1)}>+ 1',false),
			array('{host:key.last(1)}&+ 1',false),
			array('{host:key.last(1)}|+ 1',false),

			array('{host:key.diff()} + 1',true),
			array('{host:key.diff()} - 1',true),
			array('{host:key.diff()} / 1',true),
			array('{host:key.diff()} * 1',true),
			array('{host:key.diff()} = 1',true),
			array('{host:key.diff()} # 1',true),
			array('{host:key.diff()} & 1',true),
			array('{host:key.diff()} | 1',true),

			array('{host:key.diff()}+ 1',true),
			array('{host:key.diff()}- 1',true),
			array('{host:key.diff()}/ 1',true),
			array('{host:key.diff()}* 1',true),
			array('{host:key.diff()}= 1',true),
			array('{host:key.diff()}# 1',true),
			array('{host:key.diff()}& 1',true),
			array('{host:key.diff()}| 1',true),

			array('{host:key.diff()} +1',true),
			array('{host:key.diff()} -1',true),
			array('{host:key.diff()} /1',true),
			array('{host:key.diff()} *1',true),
			array('{host:key.diff()} =1',true),
			array('{host:key.diff()} #1',true),
			array('{host:key.diff()} &1',true),
			array('{host:key.diff()} |1',true),

			array('{host:key.diff()}+1',true),
			array('{host:key.diff()}-1',true),
			array('{host:key.diff()}/1',true),
			array('{host:key.diff()}*1',true),
			array('{host:key.diff()}=1',true),
			array('{host:key.diff()}#1',true),
			array('{host:key.diff()}&1',true),
			array('{host:key.diff()}|1',true),

			array('{host:key.diff()}=1K',true),
			array('{host:key.diff()}=1M',true),
			array('{host:key.diff()}=1G',true),
			array('{host:key.diff()}=1T',true),
			array('{host:key.diff()}=1s',true),
			array('{host:key.diff()}=1m',true),
			array('{host:key.diff()}=1h',true),
			array('{host:key.diff()}=1d',true),
			array('{host:key.diff()}=1w',true),

			array('{host:key.diff()}=1.56K',true),
			array('{host:key.diff()}=1.56M',true),
			array('{host:key.diff()}=1.56G',true),
			array('{host:key.diff()}=1.56T',true),
			array('{host:key.diff()}=1.56s',true),
			array('{host:key.diff()}=1.56m',true),
			array('{host:key.diff()}=1.56h',true),
			array('{host:key.diff()}=1.56d',true),
			array('{host:key.diff()}=1.56w',true),

			array('{host:key.diff()} + 1.173640',true),
			array('{host:key.diff()} - 1.173640',true),
			array('{host:key.diff()} / 1.173640',true),
			array('{host:key.diff()} * 1.173640',true),
			array('{host:key.diff()} = 1.173640',true),
			array('{host:key.diff()} # 1.173640',true),
			array('{host:key.diff()} & 1.173640',true),
			array('{host:key.diff()} | 1.173640',true),

			array('{host:key.diff()}+ 1.173640',true),
			array('{host:key.diff()}- 1.173640',true),
			array('{host:key.diff()}/ 1.173640',true),
			array('{host:key.diff()}* 1.173640',true),
			array('{host:key.diff()}= 1.173640',true),
			array('{host:key.diff()}# 1.173640',true),
			array('{host:key.diff()}& 1.173640',true),
			array('{host:key.diff()}| 1.173640',true),

			array('{host:key.diff()} +1.173640',true),
			array('{host:key.diff()} -1.173640',true),
			array('{host:key.diff()} /1.173640',true),
			array('{host:key.diff()} *1.173640',true),
			array('{host:key.diff()} =1.173640',true),
			array('{host:key.diff()} #1.173640',true),
			array('{host:key.diff()} &1.173640',true),
			array('{host:key.diff()} |1.173640',true),

			array('{host:key.diff()}+1.173640',true),
			array('{host:key.diff()}-1.173640',true),
			array('{host:key.diff()}/1.173640',true),
			array('{host:key.diff()}*1.173640',true),
			array('{host:key.diff()}=1.173640',true),
			array('{host:key.diff()}#1.173640',true),
			array('{host:key.diff()}&1.173640',true),
			array('{host:key.diff()}|1.173640',true),

			array('{host:key.diff()} + 1 | {host:key.diff()}',true),
			array('{host:key.diff()} - 1 & {host:key.diff()}',true),
			array('{host:key.diff()} / 1 # {host:key.diff()}',true),
			array('{host:key.diff()} * 1 = {host:key.diff()}',true),
			array('{host:key.diff()} = 1 * {host:key.diff()}',true),
			array('{host:key.diff()} # 1 / {host:key.diff()}',true),
			array('{host:key.diff()} & 1 - {host:key.diff()}',true),
			array('{host:key.diff()} | 1 + {host:key.diff()}',true),

			array('{host:key.diff()} -- 1',true),
			array('{host:key.diff()} ++ 1',false),
			array('{host:key.diff()} // 1',false),
			array('{host:key.diff()} ** 1',false),
			array('{host:key.diff()} == 1',false),
			array('{host:key.diff()} ## 1',false),
			array('{host:key.diff()} && 1',false),
			array('{host:key.diff()} || 1',false),

			array('{host:key.diff()} +',false),
			array('{host:key.diff()} -',false),
			array('{host:key.diff()} /',false),
			array('{host:key.diff()} *',false),
			array('{host:key.diff()} =',false),
			array('{host:key.diff()} #',false),
			array('{host:key.diff()} &',false),
			array('{host:key.diff()} |',false),

			array('- {host:key.diff()}',true),
			array('+ {host:key.diff()}',false),
			array('/ {host:key.diff()}',false),
			array('* {host:key.diff()}',false),
			array('= {host:key.diff()}',false),
			array('# {host:key.diff()}',false),
			array('& {host:key.diff()}',false),
			array('| {host:key.diff()}',false),

			array('{host:key.diff()}=0',true),
			array('{host:key.count(1,)}=0',true),
			array('{host:key.count( 1,)}=0',true),
			array('{host:key.count(  1,)}=0',true),
			array('{host:key.count(1, )}=0',true),
			array('{host:key.count(1,  )}=0',true),

			array('{host:key.str(")}=0',false),
			array('{host:key.str("")}=0',true),
			array('{host:key.str(""")}=0',false),
			array('{host:key.str("""")}=0',false),

			array('{host:key.str( ")}=0',false),
			array('{host:key.str( "")}=0',true),
			array('{host:key.str( """)}=0',false),
			array('{host:key.str( """")}=0',false),

			array('{host:key.str(  ")}=0',false),
			array('{host:key.str(  "")}=0',true),
			array('{host:key.str(  """)}=0',false),
			array('{host:key.str(  """")}=0',false),

			array('{host:key.count(1,")}=0',false),
			array('{host:key.count(1,"")}=0',true),
			array('{host:key.count(1,""")}=0',false),
			array('{host:key.count(1,"""")}=0',false),

			array('{host:key.count(1, ")}=0',false),
			array('{host:key.count(1, "")}=0',true),
			array('{host:key.count(1, """)}=0',false),
			array('{host:key.count(1, """")}=0',false),

			array('{host:key.count(1,  ")}=0',false),
			array('{host:key.count(1,  "")}=0',true),
			array('{host:key.count(1,  """)}=0',false),
			array('{host:key.count(1,  """")}=0',false),

			array('{host:key.count(1,"",")}=0',false),
			array('{host:key.count(1,"","")}=0',true),
			array('{host:key.count(1,"",""")}=0',false),
			array('{host:key.count(1,"","""")}=0',false),

			array('{host:key.count(1,"", ")}=0',false),
			array('{host:key.count(1,"", "")}=0',true),
			array('{host:key.count(1,"", """)}=0',false),
			array('{host:key.count(1,"", """")}=0',false),

			array('{host:key.count(1,"",  ")}=0',false),
			array('{host:key.count(1,"",  "")}=0',true),
			array('{host:key.count(1,"",  """)}=0',false),
			array('{host:key.count(1,"",  """")}=0',false),

			array('{host:key.str("\")}=0',false),
			array('{host:key.str("\"")}=0',true),
			array('{host:key.str("\\\\"")}=0',true),
			array('{host:key.str("\""")}=0',false),
			array('{host:key.str("\"""")}=0',false),

			array('{host:key.str(\")}=0',true),
			array('{host:key.str(param\")}=0',true),
			array('{host:key.str(param")}=0',true),

			array('{host:key.str( \")}=0',true),
			array('{host:key.str( param\")}=0',true),
			array('{host:key.str( param")}=0',true),

			array('{host:key.str(  \")}=0',true),
			array('{host:key.str(  param\")}=0',true),
			array('{host:key.str(  param")}=0',true),

			array('{host:key.str(()}=0',true),
			array('{host:key.str(param()}=0',true),

			array('{host:key.str( ()}=0',true),
			array('{host:key.str( param()}=0',true),

			array('{host:key.str(  ()}=0',true),
			array('{host:key.str(  param()}=0',true),

			array('{host:key.str())}=0',false),
			array('{host:key.str(param))}=0',false),

			array('{host:key.str( ))}=0',false),
			array('{host:key.str( param))}=0',false),

			array('{host:key.str(  ))}=0',false),
			array('{host:key.str(  param))}=0',false),

			array('{host:key.str("(")}=0',true),
			array('{host:key.str("param(")}=0',true),

			array('{host:key.str(")")}=0',true),
			array('{host:key.str("param)")}=0',true),

			array('{host:key.str()}=0',true),
			array('{host:key.str( )}=0',true),
			array('{host:key.str(" ")}=0',true),
			array('{host:key.str(abc)}=0',true),
			array('{host:key.str(\'abc\')}=0',true),
			array('{host:key.str("")}=0',true),
			array('{host:key.last(0)}=0',true),
			array('{host:key.str(aaa()}=0',true),

			array('{host:key.last(0)}=0',true),
			array('{host:key.str(aaa()}=0',true),
			array('({hostA:keyA.str("abc")}=0) | ({hostB:keyB.last(123)}=0)',true),
			array('{host:key[asd[].str(aaa()}=0',true),
			array('{host:key["param].diff()"].diff()}=0',true),
			array('{host:key[param].diff()].diff()}',false),
			array('{host:key[asd[,asd[,[]].str(aaa()}=0',true),
			array('{host:key[[],[],[]].str()}=0',true),
			array('{host:key[].count(1,[],[])}=0',true),
			array('({hostA:keyA.str("abc")}) / ({hostB:keyB.last(123)})=(0)',true),
			array('({hostA:keyA.str("abc")}=0) | ({hostB:keyB.last(123)}=0)',true),
			array('({hostA:keyA.str("abc")}=0) & ({hostB:keyB.last(123)}=0)',true),
	// Incorrect trigger expressions
			array('{hostkey.last(0)}=0',false),
			array('{host:keylast(0)}=0',false),
			array('{host:key.last(0}=0',false),
			array('{host:key.last(0)}=',false),
			array('{host:key.str()=0',false),
			array('{host:key.last()}#0}',false),
			array('{host:key.incorrect()}=0',false),
			array('{host:key.str()}<>0',false),
			array('({host:key.str(aaa()}=0',false),
			array('(({host:key.str(aaa()}=0)',false),
			array('{host:key.str(aaa()}=0)',false),
			array('({hostA:keyA.str("abc")}=0) || ({hostB:keyB.last(123)}=0)',false),
			array('{host:key.last()}<>0',false),
			array('{hostA:keyA.str("abc")} / ({hostB:keyB.last(123)}=0',false),
			array('({hostA:keyA.str("abc")} / ({hostB:keyB.last(123)})=0',false),
	// by Aleksandrs
			array('{constant}', false),
			array('{cons tant}', false),
			array('{expression}', false),
			array('{expre ssion}', false),
			array('host:key.str()', false),
			array('{host:key.str()', false),
			array('host:key.str()}', false),
			array(' {host:key.str()}', true),
			array('{host:key.str()} ', true),
			array('{ host:key.str()}', true),
			array('{host :key.str()}', true),
			array('{host:key.str(-5)}', true),
			array('{host:key.str(+5)}', true),
			array('{host:key.str([-5)}', true),
			array('{host:key.str(-5])}', true),
			array('{host:key.str((-5)}', true),
			array('{host:key.str(-5))}', false),
			array('{host:key.str(-5)*1}', false),
			array('0={host:key["a"b].str()}', false),
			array('0={host:key[].str(a"b"c)}', true),
			array('0={host:key[].str("a\"b\"c")}', true),
			array('0={host:key[].str("a\\\\"b\\\\"c")}', true),
			array('0={host:key[].str("a"b)}', false),
			array('0={host:key[].str(,"a"b,)}', false),
			array('0={host:key[].str("","a"b,"")}', false),
			array('0={host:key.str)', false),
			array('1z={host:key.str()', false),
			array('1z={host:key.str()}', false),
			array('0={host:key[].str(")}', false),
			array('0={host:key[].str( ")}', false),
			array('0={host:key[].str(")}")}', true),
			array('0={host:key[].str( ")}")}', true),
			array('({host1:key1.last(0)}/{host2:key2.last(5)})/10+2*{TRIGGER.VALUE}&{$USERMACRO1}+(-{$USERMACRO2})+-{$USERMACRO3}*-12K+12.5m', true),
			array('-12+{TRIGGER.VALUE}/(({host1:key1[].last(5)}+(5*(1-(-3*5&((7|9))#1)*{host2:key2[""].last(123)})/10/10/10)+{$USERMACRO1})-{$USERMACRO2})', true),
			array('{host:key["{$USERMACRO1}",{$USERMACRO2}].str()}', true),
			array('{host:key[].str("{$USERMACRO1}",{$USERMACRO2})}', true),
			array('{host:key["{HOSTNAME1}",{HOSTNAME2}].str()}', true),
			array('{host:key[].str("{HOSTNAME1}",{HOSTNAME2})}', false),
			array('{host:key[].count(1,"{HOSTNAME1}",{HOSTNAME2})}', true),
			array('{host:key[].str()}=-1=--2=---3=----4=-----5', false),
			array('{host:key[].str()}=-1=--2=---3=----4=-----5', false),
	// by Aleksandrs (January 6, 2011)
			array('{host:key[].str()}=-1', true),
			array('{host:key[].str()}+-1', true),
			array('{host:key[].str()}--1', true),
			array('{host:key[].str()}-(-1)', true),
			array('{host:key[].str()}-(-(-(-1)))', false),
			array('{host:key[{$$$},"{$$$}"].str()}', true),
			array('{host:key[{!!!},"{!!!}"].str()}', true),
			array('{host:key[{$USERMACRO1,"{$USERMACRO"].str()}', true),
			array('{host:key[].count(1,{$USERMACRO1,"{$USERMACRO")}', true),
			array('{host:key[{$USERMACRO1}abc,"{$USERMACRO2}"].str()}', true),
			array('{host:key[{$USERMACRO1},"{$USERMACRO2}abc"].str()}', true),
			array('{host:key[].count(1,{$USERMACRO1}abc,"{$USERMACRO2}")}', true),
			array('{host:key[].count(1,{$USERMACRO1},"{$USERMACRO2}abc")}', true),
			array('{host:key[abc{HOSTNAME1},"{HOSTNAME2}"].str()}', true),
			array('{host:key[{HOSTNAME1},"abc{HOSTNAME2}"].str()}', true),
			array('{host:key[].count(1,abc{HOSTNAME1},"{HOSTNAME2}")}', true),
			array('{host:key[].count(1,{HOSTNAME1},"abc{HOSTNAME2}")}', true),
			array('{host:key[{host:key.last(0)},"{host:key.last(0)}"].str()}', true),
			array('{host:key[].count(1,{host:key.last(0)},"{host:key.last(0)}")}', false),
			array('{host:key[].count(1,{host:key.last(0},"{host:key.last(0)}")}', true),
			array('{host:key[].count(1,{host:key.last(0)}+{host:key.last(0)}', true),
			array('{host:key[].count(1,{host:key.last(0)}', true),
			array('{host:key[{host:key[].last(0)},"{host:key[].last(0)}"].str()}', false),
			array('{host:key["{host:key[].last(0)}",{host:key[].last(0)}].str()}', false),
			array('{host:key["{host:key[].last(0)}",{host:key[].last(0)}', true),
			array('{host:key[{host:key[].last(0)}+{host:key[].last(0)}', true),
			array('{host:key[{host:key[].last(0)}', true),
	// by Aleksandrs (January 14, 2011)
			array('{host:key.last({$UPPERCASE})}', true),
			array('{host:key.last(0)}+{$UPPERCASE}', true),
			array('{host:key.last({$lowercase})}', false),
			array('{host:key.last(0)}+{$lowercase}', false),
	// by Aleksandrs (January 14, 2011)
			array('{host:key.last(1.23)}', false),
			array('{host:key.last(1.23s)}', false),
			array('{host:key.last(#1.23)}', false),
	// by Aleksandrs (January 14 and January 19, 2011)
			array('{host:key.abschange()}', true),
			array('{host:key.abschange(0)}', true),
			array('{host:key.abschange(0,)}', false),
			array('{host:key.avg()}', false),
			array('{host:key.avg(123)}', true),
			array('{host:key.avg(123s)}', true),
			array('{host:key.avg(#123)}', true),
			array('{host:key.avg(123,456)}', true),
			array('{host:key.avg(123,456s)}', true),
			array('{host:key.avg(123,456s,)}', false),
			array('{host:key.change()}', true),
			array('{host:key.change(0)}', true),
			array('{host:key.change(0,)}', false),
			array('{host:key.count()}', false),
			array('{host:key.count(123)}', true),
			array('{host:key.count(123,text)}', true),
			array('{host:key.count(123s,text)}', true),
			array('{host:key.count(#123,text)}', true),
			array('{host:key.count(123,text,eq)}', true),
			array('{host:key.count(123,text,ne)}', true),
			array('{host:key.count(123,text,gt)}', true),
			array('{host:key.count(123,text,ge)}', true),
			array('{host:key.count(123,text,lt)}', true),
			array('{host:key.count(123,text,le)}', true),
			array('{host:key.count(123,text,like)}', true),
			array('{host:key.count(123,text,like,456)}', true),
			array('{host:key.count(123,text,like,456s)}', true),
			array('{host:key.count(123,text,nonexistent,456s)}', true),
			array('{host:key.count(123,text,nonexistent,456s,)}', false),
			array('{host:key.date()}', true),
			array('{host:key.date(0)}', true),
			array('{host:key.date(0,)}', false),
			array('{host:key.dayofweek()}', true),
			array('{host:key.dayofweek(0)}', true),
			array('{host:key.dayofweek(0,)}', false),
			array('{host:key.delta()}', false),
			array('{host:key.delta(123)}', true),
			array('{host:key.delta(123s)}', true),
			array('{host:key.delta(#123)}', true),
			array('{host:key.delta(123,456)}', true),
			array('{host:key.delta(123,456s)}', true),
			array('{host:key.delta(123,456s,)}', false),
			array('{host:key.diff()}', true),
			array('{host:key.diff(0)}', true),
			array('{host:key.diff(0,)}', false),
			array('{host:key.fuzzytime()}', false),
			array('{host:key.fuzzytime(123)}', true),
			array('{host:key.fuzzytime(#123)}', false),
			array('{host:key.fuzzytime(123,)}', false),
			array('{host:key.iregexp()}', true),
			array('{host:key.iregexp(text)}', true),
			array('{host:key.iregexp(text,123)}', true),
			array('{host:key.iregexp(text,123s)}', true),
			array('{host:key.iregexp(text,#123)}', true),
			array('{host:key.iregexp(text,#123,)}', false),
			array('{host:key.last()}', false),
			array('{host:key.last(0)}', true),
			array('{host:key.last(#123)}', true),
			array('{host:key.last(#123,456)}', true),
			array('{host:key.last(#123,456s)}', true),
			array('{host:key.last(#123,456s,)}', false),
			array('{host:key.logseverity()}', true),
			array('{host:key.logseverity(0)}', true),
			array('{host:key.logseverity(0,)}', false),
			array('{host:key.logsource()}', true),
			array('{host:key.logsource(text)}', true),
			array('{host:key.logsource(text,)}', false),
			array('{host:key.max()}', false),
			array('{host:key.max(123)}', true),
			array('{host:key.max(123s)}', true),
			array('{host:key.max(#123)}', true),
			array('{host:key.max(123,456)}', true),
			array('{host:key.max(123,456s)}', true),
			array('{host:key.max(123,456s,)}', false),
			array('{host:key.min()}', false),
			array('{host:key.min(123)}', true),
			array('{host:key.min(123s)}', true),
			array('{host:key.min(#123)}', true),
			array('{host:key.min(123,456)}', true),
			array('{host:key.min(123,456s)}', true),
			array('{host:key.min(123,456s,)}', false),
			array('{host:key.nodata()}', false),
			array('{host:key.nodata(123)}', true),
			array('{host:key.nodata(123s)}', true),
			array('{host:key.nodata(#123)}', false),
			array('{host:key.nodata(123s,)}', false),
			array('{host:key.now()}', true),
			array('{host:key.now(0)}', true),
			array('{host:key.now(0,)}', false),
			array('{host:key.prev()}', true),
			array('{host:key.prev(0)}', true),
			array('{host:key.prev(0,)}', false),
			array('{host:key.regexp()}', true),
			array('{host:key.regexp(text)}', true),
			array('{host:key.regexp(text,123)}', true),
			array('{host:key.regexp(text,123s)}', true),
			array('{host:key.regexp(text,#123)}', true),
			array('{host:key.regexp(text,#123,)}', false),
			array('{host:key.str()}', true),
			array('{host:key.str(text)}', true),
			array('{host:key.str(text,123)}', true),
			array('{host:key.str(text,123s)}', true),
			array('{host:key.str(text,#123)}', true),
			array('{host:key.str(text,#123,)}', false),
			array('{host:key.strlen()}', false),
			array('{host:key.strlen(0)}', true),
			array('{host:key.strlen(#123)}', true),
			array('{host:key.strlen(#123,456)}', true),
			array('{host:key.strlen(#123,456s)}', true),
			array('{host:key.strlen(#123,456s,)}', false),
			array('{host:key.sum()}', false),
			array('{host:key.sum(123)}', true),
			array('{host:key.sum(123s)}', true),
			array('{host:key.sum(#123)}', true),
			array('{host:key.sum(123,456)}', true),
			array('{host:key.sum(123,456s)}', true),
			array('{host:key.sum(123,456s,)}', false),
			array('{host:key.time()}', true),
			array('{host:key.time(0)}', true),
			array('{host:key.time(0,)}', false),
			array('{host:key.nonexistent()}', false),
	// by Aleksandrs (January 18, 2011)
			array('{host:key.last(0)}+{TRIGGER.VALUE}', true),
			array('{host:key.last(0)}+{trigger.value}', false),
	// by Alexei's gen.php (January 7-14, 2011)
			array('(({host:key.last(0)}+1.)) + + (({host:key.last(0)}+1.))',false),
			array('(({host:key.last(0)}+1.)) + - (({host:key.last(0)}+1.))',false),
			array('(({host:key.last(0)}+1.)) + (({host:key.last(0)}+1.))',false),
			array('(({host:key.last(0)}+1.))',false),
			array('(--({host:key.last(0)}+1.))',false),
			array('(+({host:key.last(0)}+1.))',false),
			array('(/({host:key.last(0)}+1.))',false),
			array('({host:key.last(0)}+1.)/({host:key.last(0)}+1.)',false),
			array('({host:key.last(0)}+1.)-({host:key.last(0)}+1.)',false),
			array('({host:key.last(0)}+1.)+({host:key.last(0)}+1.)',false),
			array('({host:key.last(0)}+1.)|({host:key.last(0)}+1.)',false),
			array('({host:key.last(0)}+1.)&({host:key.last(0)}+1.)',false),
			array('({host:key.last(0)}+1.)&({host:key.last(0)}+1.)/({host:key.last(0)}+1.)',false),
			array('({host:key.last(0)}+1.)+({host:key.last(0)}+1.)/({host:key.last(0)}+1.)',false),
			array('1 - (1/({host:key.last(0)}+1.))+(({host:key.last(0)}+1.))/({host:key.last(0)}+1.)/({host:key.last(0)}+1.)',false),
			array('(({host:key.last(0)}+.1)) + + (({host:key.last(0)}+.1))',false),
			array('(({host:key.last(0)}+.1)) + - (({host:key.last(0)}+.1))',false),
			array('(({host:key.last(0)}+.1)) + (({host:key.last(0)}+.1))',false),
			array('(({host:key.last(0)}+.1))',false),
			array('(--({host:key.last(0)}+.1))',false),
			array('(+({host:key.last(0)}+.1))',false),
			array('(/({host:key.last(0)}+.1))',false),
			array('({host:key.last(0)}+.1)/({host:key.last(0)}+.1)',false),
			array('({host:key.last(0)}+.1)-({host:key.last(0)}+.1)',false),
			array('({host:key.last(0)}+.1)+({host:key.last(0)}+.1)',false),
			array('({host:key.last(0)}+.1)|({host:key.last(0)}+.1)',false),
			array('({host:key.last(0)}+.1)&({host:key.last(0)}+.1)',false),
			array('({host:key.last(0)}+.1)&({host:key.last(0)}+.1)/({host:key.last(0)}+.1)',false),
			array('({host:key.last(0)}+.1)+({host:key.last(0)}+.1)/({host:key.last(0)}+.1)',false),
			array('1 - (1/({host:key.last(0)}+.1))+(({host:key.last(0)}+.1))/({host:key.last(0)}+.1)/({host:key.last(0)}+.1)',false),
			array('(({host:key.last(0)}+0 .1)) + + (({host:key.last(0)}+0 .1))',false),
			array('(({host:key.last(0)}+0 .1)) + - (({host:key.last(0)}+0 .1))',false),
			array('(({host:key.last(0)}+0 .1)) + (({host:key.last(0)}+0 .1))',false),
			array('(({host:key.last(0)}+0 .1))',false),
			array('(--({host:key.last(0)}+0 .1))',false),
			array('(+({host:key.last(0)}+0 .1))',false),
			array('(/({host:key.last(0)}+0 .1))',false),
			array('({host:key.last(0)}+0 .1)/({host:key.last(0)}+0 .1)',false),
			array('({host:key.last(0)}+0 .1)-({host:key.last(0)}+0 .1)',false),
			array('({host:key.last(0)}+0 .1)+({host:key.last(0)}+0 .1)',false),
			array('({host:key.last(0)}+0 .1)|({host:key.last(0)}+0 .1)',false),
			array('({host:key.last(0)}+0 .1)&({host:key.last(0)}+0 .1)',false),
			array('({host:key.last(0)}+0 .1)&({host:key.last(0)}+0 .1)/({host:key.last(0)}+0 .1)',false),
			array('({host:key.last(0)}+0 .1)+({host:key.last(0)}+0 .1)/({host:key.last(0)}+0 .1)',false),
			array('1 - (1/({host:key.last(0)}+0 .1))+(({host:key.last(0)}+0 .1))/({host:key.last(0)}+0 .1)/({host:key.last(0)}+0 .1)',false),
			array('(({host:key.last(0)}+1 K)) + + (({host:key.last(0)}+1 K))',false),
			array('(({host:key.last(0)}+1 K)) + - (({host:key.last(0)}+1 K))',false),
			array('(({host:key.last(0)}+1 K)) + (({host:key.last(0)}+1 K))',false),
			array('(({host:key.last(0)}+1 K))',false),
			array('(--({host:key.last(0)}+1 K))',false),
			array('(+({host:key.last(0)}+1 K))',false),
			array('(/({host:key.last(0)}+1 K))',false),
			array('({host:key.last(0)}+1 K)/({host:key.last(0)}+1 K)',false),
			array('({host:key.last(0)}+1 K)-({host:key.last(0)}+1 K)',false),
			array('({host:key.last(0)}+1 K)+({host:key.last(0)}+1 K)',false),
			array('({host:key.last(0)}+1 K)|({host:key.last(0)}+1 K)',false),
			array('({host:key.last(0)}+1 K)&({host:key.last(0)}+1 K)',false),
			array('({host:key.last(0)}+1 K)&({host:key.last(0)}+1 K)/({host:key.last(0)}+1 K)',false),
			array('({host:key.last(0)}+1 K)+({host:key.last(0)}+1 K)/({host:key.last(0)}+1 K)',false),
			array('1 - (1/({host:key.last(0)}+1 K))+(({host:key.last(0)}+1 K))/({host:key.last(0)}+1 K)/({host:key.last(0)}+1 K)',false),
			array('(({host:key.last(0)}+.)) + + (({host:key.last(0)}+.))',false),
			array('(({host:key.last(0)}+.)) + - (({host:key.last(0)}+.))',false),
			array('(({host:key.last(0)}+.)) + (({host:key.last(0)}+.))',false),
			array('(({host:key.last(0)}+.))',false),
			array('(--({host:key.last(0)}+.))',false),
			array('(+({host:key.last(0)}+.))',false),
			array('(/({host:key.last(0)}+.))',false),
			array('({host:key.last(0)}+.)/({host:key.last(0)}+.)',false),
			array('({host:key.last(0)}+.)-({host:key.last(0)}+.)',false),
			array('({host:key.last(0)}+.)+({host:key.last(0)}+.)',false),
			array('({host:key.last(0)}+.)|({host:key.last(0)}+.)',false),
			array('({host:key.last(0)}+.)&({host:key.last(0)}+.)',false),
			array('({host:key.last(0)}+.)&({host:key.last(0)}+.)/({host:key.last(0)}+.)',false),
			array('({host:key.last(0)}+.)+({host:key.last(0)}+.)/({host:key.last(0)}+.)',false),
			array('1 - (1/({host:key.last(0)}+.))+(({host:key.last(0)}+.))/({host:key.last(0)}+.)/({host:key.last(0)}+.)',false),
			array('(({host:key.last(0)}+.K)) + + (({host:key.last(0)}+.K))',false),
			array('(({host:key.last(0)}+.K)) + - (({host:key.last(0)}+.K))',false),
			array('(({host:key.last(0)}+.K)) + (({host:key.last(0)}+.K))',false),
			array('(({host:key.last(0)}+.K))',false),
			array('(--({host:key.last(0)}+.K))',false),
			array('(+({host:key.last(0)}+.K))',false),
			array('(/({host:key.last(0)}+.K))',false),
			array('({host:key.last(0)}+.K)/({host:key.last(0)}+.K)',false),
			array('({host:key.last(0)}+.K)-({host:key.last(0)}+.K)',false),
			array('({host:key.last(0)}+.K)+({host:key.last(0)}+.K)',false),
			array('({host:key.last(0)}+.K)|({host:key.last(0)}+.K)',false),
			array('({host:key.last(0)}+.K)&({host:key.last(0)}+.K)',false),
			array('({host:key.last(0)}+.K)&({host:key.last(0)}+.K)/({host:key.last(0)}+.K)',false),
			array('({host:key.last(0)}+.K)+({host:key.last(0)}+.K)/({host:key.last(0)}+.K)',false),
			array('1 - (1/({host:key.last(0)}+.K))+(({host:key.last(0)}+.K))/({host:key.last(0)}+.K)/({host:key.last(0)}+.K)',false),
			array('(({host:key.last(0)}+K)) + + (({host:key.last(0)}+K))',false),
			array('(({host:key.last(0)}+K)) + - (({host:key.last(0)}+K))',false),
			array('(({host:key.last(0)}+K)) + (({host:key.last(0)}+K))',false),
			array('(({host:key.last(0)}+K))',false),
			array('(--({host:key.last(0)}+K))',false),
			array('(+({host:key.last(0)}+K))',false),
			array('(/({host:key.last(0)}+K))',false),
			array('({host:key.last(0)}+K)/({host:key.last(0)}+K)',false),
			array('({host:key.last(0)}+K)-({host:key.last(0)}+K)',false),
			array('({host:key.last(0)}+K)+({host:key.last(0)}+K)',false),
			array('({host:key.last(0)}+K)|({host:key.last(0)}+K)',false),
			array('({host:key.last(0)}+K)&({host:key.last(0)}+K)',false),
			array('({host:key.last(0)}+K)&({host:key.last(0)}+K)/({host:key.last(0)}+K)',false),
			array('({host:key.last(0)}+K)+({host:key.last(0)}+K)/({host:key.last(0)}+K)',false),
			array('1 - (1/({host:key.last(0)}+K))+(({host:key.last(0)}+K))/({host:key.last(0)}+K)/({host:key.last(0)}+K)',false),
			array('({host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)}) + + ({host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)})',false),
			array('({host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)}) + - ({host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)})',false),
			array('({host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)}) + ({host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)})',true),
			array('({host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)})',true),
			array('(--{host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)})',false),
			array('(+{host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)})',false),
			array('(/{host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)})',false),
			array('{host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)}/{host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)}',true),
			array('{host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)}-{host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)}',true),
			array('{host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)}+{host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)}',true),
			array('{host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)}|{host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)}',true),
			array('{host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)}&{host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)}',true),
			array('{host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)}&{host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)}/{host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)}',true),
			array('{host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)}+{host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)}/{host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)}',true),
			array('1 - (1/{host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)})+({host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)})/{host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)}/{host:key.last(1)}+(1/2+2*2-3|4)|23-34>{host:key.last(#1)}',true),
			array('({host:key.last(0)}+(1/2+2*2-3|4)|23-34) + + ({host:key.last(0)}+(1/2+2*2-3|4)|23-34)',false),
			array('({host:key.last(0)}+(1/2+2*2-3|4)|23-34) + - ({host:key.last(0)}+(1/2+2*2-3|4)|23-34)',false),
			array('({host:key.last(0)}+(1/2+2*2-3|4)|23-34) + ({host:key.last(0)}+(1/2+2*2-3|4)|23-34)',true),
			array('({host:key.last(0)}+(1/2+2*2-3|4)|23-34)',true),
			array('(--{host:key.last(0)}+(1/2+2*2-3|4)|23-34)',false),
			array('(+{host:key.last(0)}+(1/2+2*2-3|4)|23-34)',false),
			array('(/{host:key.last(0)}+(1/2+2*2-3|4)|23-34)',false),
			array('{host:key.last(0)}+(1/2+2*2-3|4)|23-34/{host:key.last(0)}+(1/2+2*2-3|4)|23-34',true),
			array('{host:key.last(0)}+(1/2+2*2-3|4)|23-34-{host:key.last(0)}+(1/2+2*2-3|4)|23-34',true),
			array('{host:key.last(0)}+(1/2+2*2-3|4)|23-34+{host:key.last(0)}+(1/2+2*2-3|4)|23-34',true),
			array('{host:key.last(0)}+(1/2+2*2-3|4)|23-34|{host:key.last(0)}+(1/2+2*2-3|4)|23-34',true),
			array('{host:key.last(0)}+(1/2+2*2-3|4)|23-34&{host:key.last(0)}+(1/2+2*2-3|4)|23-34',true),
			array('{host:key.last(0)}+(1/2+2*2-3|4)|23-34&{host:key.last(0)}+(1/2+2*2-3|4)|23-34/{host:key.last(0)}+(1/2+2*2-3|4)|23-34',true),
			array('{host:key.last(0)}+(1/2+2*2-3|4)|23-34+{host:key.last(0)}+(1/2+2*2-3|4)|23-34/{host:key.last(0)}+(1/2+2*2-3|4)|23-34',true),
			array('1 - (1/{host:key.last(0)}+(1/2+2*2-3|4)|23-34)+({host:key.last(0)}+(1/2+2*2-3|4)|23-34)/{host:key.last(0)}+(1/2+2*2-3|4)|23-34/{host:key.last(0)}+(1/2+2*2-3|4)|23-34',true),
			array('({host:key.{a}}) + + ({host:key.{a}})',false),
			array('({host:key.{a}}) + - ({host:key.{a}})',false),
			array('({host:key.{a}}) + ({host:key.{a}})',false),
			array('({host:key.{a}})',false),
			array('(--{host:key.{a}})',false),
			array('(+{host:key.{a}})',false),
			array('(/{host:key.{a}})',false),
			array('{host:key.{a}}/{host:key.{a}}',false),
			array('{host:key.{a}}-{host:key.{a}}',false),
			array('{host:key.{a}}+{host:key.{a}}',false),
			array('{host:key.{a}}|{host:key.{a}}',false),
			array('{host:key.{a}}&{host:key.{a}}',false),
			array('{host:key.{a}}&{host:key.{a}}/{host:key.{a}}',false),
			array('{host:key.{a}}+{host:key.{a}}/{host:key.{a}}',false),
			array('1 - (1/{host:key.{a}})+({host:key.{a}})/{host:key.{a}}/{host:key.{a}}',false),
			array('({host::key.last{a}}) + + ({host::key.last{a}})',false),
			array('({host::key.last{a}}) + - ({host::key.last{a}})',false),
			array('({host::key.last{a}}) + ({host::key.last{a}})',false),
			array('({host::key.last{a}})',false),
			array('(--{host::key.last{a}})',false),
			array('(+{host::key.last{a}})',false),
			array('(/{host::key.last{a}})',false),
			array('{host::key.last{a}}/{host::key.last{a}}',false),
			array('{host::key.last{a}}-{host::key.last{a}}',false),
			array('{host::key.last{a}}+{host::key.last{a}}',false),
			array('{host::key.last{a}}|{host::key.last{a}}',false),
			array('{host::key.last{a}}&{host::key.last{a}}',false),
			array('{host::key.last{a}}&{host::key.last{a}}/{host::key.last{a}}',false),
			array('{host::key.last{a}}+{host::key.last{a}}/{host::key.last{a}}',false),
			array('1 - (1/{host::key.last{a}})+({host::key.last{a}})/{host::key.last{a}}/{host::key.last{a}}',false),
			array('({host::key.(0)}) + + ({host::key.(0)})',false),
			array('({host::key.(0)}) + - ({host::key.(0)})',false),
			array('({host::key.(0)}) + ({host::key.(0)})',false),
			array('({host::key.(0)})',false),
			array('(--{host::key.(0)})',false),
			array('(+{host::key.(0)})',false),
			array('(/{host::key.(0)})',false),
			array('{host::key.(0)}/{host::key.(0)}',false),
			array('{host::key.(0)}-{host::key.(0)}',false),
			array('{host::key.(0)}+{host::key.(0)}',false),
			array('{host::key.(0)}|{host::key.(0)}',false),
			array('{host::key.(0)}&{host::key.(0)}',false),
			array('{host::key.(0)}&{host::key.(0)}/{host::key.(0)}',false),
			array('{host::key.(0)}+{host::key.(0)}/{host::key.(0)}',false),
			array('1 - (1/{host::key.(0)})+({host::key.(0)})/{host::key.(0)}/{host::key.(0)}',false),
			array('({:key.(0)}) + + ({:key.(0)})',false),
			array('({:key.(0)}) + - ({:key.(0)})',false),
			array('({:key.(0)}) + ({:key.(0)})',false),
			array('({:key.(0)})',false),
			array('(--{:key.(0)})',false),
			array('(+{:key.(0)})',false),
			array('(/{:key.(0)})',false),
			array('{:key.(0)}/{:key.(0)}',false),
			array('{:key.(0)}-{:key.(0)}',false),
			array('{:key.(0)}+{:key.(0)}',false),
			array('{:key.(0)}|{:key.(0)}',false),
			array('{:key.(0)}&{:key.(0)}',false),
			array('{:key.(0)}&{:key.(0)}/{:key.(0)}',false),
			array('{:key.(0)}+{:key.(0)}/{:key.(0)}',false),
			array('1 - (1/{:key.(0)})+({:key.(0)})/{:key.(0)}/{:key.(0)}',false),
			array('({:key.last(0)}) + + ({:key.last(0)})',false),
			array('({:key.last(0)}) + - ({:key.last(0)})',false),
			array('({:key.last(0)}) + ({:key.last(0)})',false),
			array('({:key.last(0)})',false),
			array('(--{:key.last(0)})',false),
			array('(+{:key.last(0)})',false),
			array('(/{:key.last(0)})',false),
			array('{:key.last(0)}/{:key.last(0)}',false),
			array('{:key.last(0)}-{:key.last(0)}',false),
			array('{:key.last(0)}+{:key.last(0)}',false),
			array('{:key.last(0)}|{:key.last(0)}',false),
			array('{:key.last(0)}&{:key.last(0)}',false),
			array('{:key.last(0)}&{:key.last(0)}/{:key.last(0)}',false),
			array('{:key.last(0)}+{:key.last(0)}/{:key.last(0)}',false),
			array('1 - (1/{:key.last(0)})+({:key.last(0)})/{:key.last(0)}/{:key.last(0)}',false),
			array('(({host:key.last(0)})) + + (({host:key.last(0)}))',false),
			array('(({host:key.last(0)})) + - (({host:key.last(0)}))',false),
			array('(({host:key.last(0)})) + (({host:key.last(0)}))',true),
			array('(({host:key.last(0)}))',true),
			array('(--({host:key.last(0)}))',false),
			array('(+({host:key.last(0)}))',false),
			array('(/({host:key.last(0)}))',false),
			array('({host:key.last(0)})/({host:key.last(0)})',true),
			array('({host:key.last(0)})-({host:key.last(0)})',true),
			array('({host:key.last(0)})+({host:key.last(0)})',true),
			array('({host:key.last(0)})|({host:key.last(0)})',true),
			array('({host:key.last(0)})&({host:key.last(0)})',true),
			array('({host:key.last(0)})&({host:key.last(0)})/({host:key.last(0)})',true),
			array('({host:key.last(0)})+({host:key.last(0)})/({host:key.last(0)})',true),
			array('1 - (1/({host:key.last(0)}))+(({host:key.last(0)}))/({host:key.last(0)})/({host:key.last(0)})',true),
			array('({host:.last(0)}) + + ({host:.last(0)})',false),
			array('({host:.last(0)}) + - ({host:.last(0)})',false),
			array('({host:.last(0)}) + ({host:.last(0)})',false),
			array('({host:.last(0)})',false),
			array('(--{host:.last(0)})',false),
			array('(+{host:.last(0)})',false),
			array('(/{host:.last(0)})',false),
			array('{host:.last(0)}/{host:.last(0)}',false),
			array('{host:.last(0)}-{host:.last(0)}',false),
			array('{host:.last(0)}+{host:.last(0)}',false),
			array('{host:.last(0)}|{host:.last(0)}',false),
			array('{host:.last(0)}&{host:.last(0)}',false),
			array('{host:.last(0)}&{host:.last(0)}/{host:.last(0)}',false),
			array('{host:.last(0)}+{host:.last(0)}/{host:.last(0)}',false),
			array('1 - (1/{host:.last(0)})+({host:.last(0)})/{host:.last(0)}/{host:.last(0)}',false),
			array('({$}+{host:key.last(0)}) + + ({$}+{host:key.last(0)})',false),
			array('({$}+{host:key.last(0)}) + - ({$}+{host:key.last(0)})',false),
			array('({$}+{host:key.last(0)}) + ({$}+{host:key.last(0)})',false),
			array('({$}+{host:key.last(0)})',false),
			array('(--{$}+{host:key.last(0)})',false),
			array('(+{$}+{host:key.last(0)})',false),
			array('(/{$}+{host:key.last(0)})',false),
			array('{$}+{host:key.last(0)}/{$}+{host:key.last(0)}',false),
			array('{$}+{host:key.last(0)}-{$}+{host:key.last(0)}',false),
			array('{$}+{host:key.last(0)}+{$}+{host:key.last(0)}',false),
			array('{$}+{host:key.last(0)}|{$}+{host:key.last(0)}',false),
			array('{$}+{host:key.last(0)}&{$}+{host:key.last(0)}',false),
			array('{$}+{host:key.last(0)}&{$}+{host:key.last(0)}/{$}+{host:key.last(0)}',false),
			array('{$}+{host:key.last(0)}+{$}+{host:key.last(0)}/{$}+{host:key.last(0)}',false),
			array('1 - (1/{$}+{host:key.last(0)})+({$}+{host:key.last(0)})/{$}+{host:key.last(0)}/{$}+{host:key.last(0)}',false),
			array('( - {$MACRO}+{host:key.last(0)}) + + ( - {$MACRO}+{host:key.last(0)})',false),
			array('( - {$MACRO}+{host:key.last(0)}) + - ( - {$MACRO}+{host:key.last(0)})',false),
			array('( - {$MACRO}+{host:key.last(0)}) + ( - {$MACRO}+{host:key.last(0)})',true),
			array('( - {$MACRO}+{host:key.last(0)})',true),
			array('(-- - {$MACRO}+{host:key.last(0)})',false),
			array('(+ - {$MACRO}+{host:key.last(0)})',false),
			array('(/ - {$MACRO}+{host:key.last(0)})',false),
			array(' - {$MACRO}+{host:key.last(0)}/ - {$MACRO}+{host:key.last(0)}',true),
			array(' - {$MACRO}+{host:key.last(0)}- - {$MACRO}+{host:key.last(0)}',true),
			array(' - {$MACRO}+{host:key.last(0)}+ - {$MACRO}+{host:key.last(0)}',true),
			array(' - {$MACRO}+{host:key.last(0)}| - {$MACRO}+{host:key.last(0)}',true),
			array(' - {$MACRO}+{host:key.last(0)}& - {$MACRO}+{host:key.last(0)}',true),
			array(' - {$MACRO}+{host:key.last(0)}& - {$MACRO}+{host:key.last(0)}/ - {$MACRO}+{host:key.last(0)}',true),
			array(' - {$MACRO}+{host:key.last(0)}+ - {$MACRO}+{host:key.last(0)}/ - {$MACRO}+{host:key.last(0)}',true),
			array('1 - (1/ - {$MACRO}+{host:key.last(0)})+( - {$MACRO}+{host:key.last(0)})/ - {$MACRO}+{host:key.last(0)}/ - {$MACRO}+{host:key.last(0)}',true),
			array('(100G+{host:key.last(0)}) + + (100G+{host:key.last(0)})',false),
			array('(100G+{host:key.last(0)}) + - (100G+{host:key.last(0)})',false),
			array('(100G+{host:key.last(0)}) + (100G+{host:key.last(0)})',true),
			array('(100G+{host:key.last(0)})',true),
			array('(--100G+{host:key.last(0)})',false),
			array('(+100G+{host:key.last(0)})',false),
			array('(/100G+{host:key.last(0)})',false),
			array('100G+{host:key.last(0)}/100G+{host:key.last(0)}',true),
			array('100G+{host:key.last(0)}-100G+{host:key.last(0)}',true),
			array('100G+{host:key.last(0)}+100G+{host:key.last(0)}',true),
			array('100G+{host:key.last(0)}|100G+{host:key.last(0)}',true),
			array('100G+{host:key.last(0)}&100G+{host:key.last(0)}',true),
			array('100G+{host:key.last(0)}&100G+{host:key.last(0)}/100G+{host:key.last(0)}',true),
			array('100G+{host:key.last(0)}+100G+{host:key.last(0)}/100G+{host:key.last(0)}',true),
			array('1 - (1/100G+{host:key.last(0)})+(100G+{host:key.last(0)})/100G+{host:key.last(0)}/100G+{host:key.last(0)}',true),
			array('({host:key.last(0)}) + + ({host:key.last(0)})',false),
			array('({host:key.last(0)}) + - ({host:key.last(0)})',false),
			array('({host:key.last(0)}) + ({host:key.last(0)})',true),
			array('({host:key.last(0)})',true),
			array('(--{host:key.last(0)})',false),
			array('(+{host:key.last(0)})',false),
			array('(/{host:key.last(0)})',false),
			array('{host:key.last(0)}/{host:key.last(0)}',true),
			array('{host:key.last(0)}-{host:key.last(0)}',true),
			array('{host:key.last(0)}+{host:key.last(0)}',true),
			array('{host:key.last(0)}|{host:key.last(0)}',true),
			array('{host:key.last(0)}&{host:key.last(0)}',true),
			array('{host:key.last(0)}&{host:key.last(0)}/{host:key.last(0)}',true),
			array('{host:key.last(0)}+{host:key.last(0)}/{host:key.last(0)}',true),
			array('1 - (1/{host:key.last(0)})+({host:key.last(0)})/{host:key.last(0)}/{host:key.last(0)}',true),
			array('({host:key.str(0 - 1 / 2 |-4*-56.34K)}) + + ({host:key.str(0 - 1 / 2 |-4*-56.34K)})',false),
			array('({host:key.str(0 - 1 / 2 |-4*-56.34K)}) + - ({host:key.str(0 - 1 / 2 |-4*-56.34K)})',false),
			array('({host:key.str(0 - 1 / 2 |-4*-56.34K)}) + ({host:key.str(0 - 1 / 2 |-4*-56.34K)})',true),
			array('({host:key.str(0 - 1 / 2 |-4*-56.34K)})',true),
			array('(--{host:key.str(0 - 1 / 2 |-4*-56.34K)})',false),
			array('(+{host:key.str(0 - 1 / 2 |-4*-56.34K)})',false),
			array('(/{host:key.str(0 - 1 / 2 |-4*-56.34K)})',false),
			array('{host:key.str(0 - 1 / 2 |-4*-56.34K)}/{host:key.str(0 - 1 / 2 |-4*-56.34K)}',true),
			array('{host:key.str(0 - 1 / 2 |-4*-56.34K)}-{host:key.str(0 - 1 / 2 |-4*-56.34K)}',true),
			array('{host:key.str(0 - 1 / 2 |-4*-56.34K)}+{host:key.str(0 - 1 / 2 |-4*-56.34K)}',true),
			array('{host:key.str(0 - 1 / 2 |-4*-56.34K)}|{host:key.str(0 - 1 / 2 |-4*-56.34K)}',true),
			array('{host:key.str(0 - 1 / 2 |-4*-56.34K)}&{host:key.str(0 - 1 / 2 |-4*-56.34K)}',true),
			array('{host:key.str(0 - 1 / 2 |-4*-56.34K)}&{host:key.str(0 - 1 / 2 |-4*-56.34K)}/{host:key.str(0 - 1 / 2 |-4*-56.34K)}',true),
			array('{host:key.str(0 - 1 / 2 |-4*-56.34K)}+{host:key.str(0 - 1 / 2 |-4*-56.34K)}/{host:key.str(0 - 1 / 2 |-4*-56.34K)}',true),
			array('1 - (1/{host:key.str(0 - 1 / 2 |-4*-56.34K)})+({host:key.str(0 - 1 / 2 |-4*-56.34K)})/{host:key.str(0 - 1 / 2 |-4*-56.34K)}/{host:key.str(0 - 1 / 2 |-4*-56.34K)}',true),
			array('({host:key.str(^$$$^%)}) + + ({host:key.str(^$$$^%)})',false),
			array('({host:key.str(^$$$^%)}) + - ({host:key.str(^$$$^%)})',false),
			array('({host:key.str(^$$$^%)}) + ({host:key.str(^$$$^%)})',true),
			array('({host:key.str(^$$$^%)})',true),
			array('(--{host:key.str(^$$$^%)})',false),
			array('(+{host:key.str(^$$$^%)})',false),
			array('(/{host:key.str(^$$$^%)})',false),
			array('{host:key.str(^$$$^%)}/{host:key.str(^$$$^%)}',true),
			array('{host:key.str(^$$$^%)}-{host:key.str(^$$$^%)}',true),
			array('{host:key.str(^$$$^%)}+{host:key.str(^$$$^%)}',true),
			array('{host:key.str(^$$$^%)}|{host:key.str(^$$$^%)}',true),
			array('{host:key.str(^$$$^%)}&{host:key.str(^$$$^%)}',true),
			array('{host:key.str(^$$$^%)}&{host:key.str(^$$$^%)}/{host:key.str(^$$$^%)}',true),
			array('{host:key.str(^$$$^%)}+{host:key.str(^$$$^%)}/{host:key.str(^$$$^%)}',true),
			array('1 - (1/{host:key.str(^$$$^%)})+({host:key.str(^$$$^%)})/{host:key.str(^$$$^%)}/{host:key.str(^$$$^%)}',true),
			array('({host:key.str("(^*&%#$%)*")}) + + ({host:key.str("(^*&%#$%)*")})',false),
			array('({host:key.str("(^*&%#$%)*")}) + - ({host:key.str("(^*&%#$%)*")})',false),
			array('({host:key.str("(^*&%#$%)*")}) + ({host:key.str("(^*&%#$%)*")})',true),
			array('({host:key.str("(^*&%#$%)*")})',true),
			array('(--{host:key.str("(^*&%#$%)*")})',false),
			array('(+{host:key.str("(^*&%#$%)*")})',false),
			array('(/{host:key.str("(^*&%#$%)*")})',false),
			array('{host:key.str("(^*&%#$%)*")}/{host:key.str("(^*&%#$%)*")}',true),
			array('{host:key.str("(^*&%#$%)*")}-{host:key.str("(^*&%#$%)*")}',true),
			array('{host:key.str("(^*&%#$%)*")}+{host:key.str("(^*&%#$%)*")}',true),
			array('{host:key.str("(^*&%#$%)*")}|{host:key.str("(^*&%#$%)*")}',true),
			array('{host:key.str("(^*&%#$%)*")}&{host:key.str("(^*&%#$%)*")}',true),
			array('{host:key.str("(^*&%#$%)*")}&{host:key.str("(^*&%#$%)*")}/{host:key.str("(^*&%#$%)*")}',true),
			array('{host:key.str("(^*&%#$%)*")}+{host:key.str("(^*&%#$%)*")}/{host:key.str("(^*&%#$%)*")}',true),
			array('1 - (1/{host:key.str("(^*&%#$%)*")})+({host:key.str("(^*&%#$%)*")})/{host:key.str("(^*&%#$%)*")}/{host:key.str("(^*&%#$%)*")}',true),
			array('(((((((({host:key.str("")})))))))) + + (((((((({host:key.str("")}))))))))',false),
			array('(((((((({host:key.str("")})))))))) + - (((((((({host:key.str("")}))))))))',false),
			array('(((((((({host:key.str("")})))))))) + (((((((({host:key.str("")}))))))))',true),
			array('(((((((({host:key.str("")}))))))))',true),
			array('(--((((((({host:key.str("")}))))))))',false),
			array('(+((((((({host:key.str("")}))))))))',false),
			array('(/((((((({host:key.str("")}))))))))',false),
			array('((((((({host:key.str("")})))))))/((((((({host:key.str("")})))))))',true),
			array('((((((({host:key.str("")})))))))-((((((({host:key.str("")})))))))',true),
			array('((((((({host:key.str("")})))))))+((((((({host:key.str("")})))))))',true),
			array('((((((({host:key.str("")})))))))|((((((({host:key.str("")})))))))',true),
			array('((((((({host:key.str("")})))))))&((((((({host:key.str("")})))))))',true),
			array('((((((({host:key.str("")})))))))&((((((({host:key.str("")})))))))/((((((({host:key.str("")})))))))',true),
			array('((((((({host:key.str("")})))))))+((((((({host:key.str("")})))))))/((((((({host:key.str("")})))))))',true),
			array('1 - (1/((((((({host:key.str("")}))))))))+(((((((({host:key.str("")}))))))))/((((((({host:key.str("")})))))))/((((((({host:key.str("")})))))))',true),
			array('((1 - 1-2-((((((({host:key.str("0")}))))))))) + + ((1 - 1-2-((((((({host:key.str("0")})))))))))',false),
			array('((1 - 1-2-((((((({host:key.str("0")}))))))))) + - ((1 - 1-2-((((((({host:key.str("0")})))))))))',false),
			array('((1 - 1-2-((((((({host:key.str("0")}))))))))) + ((1 - 1-2-((((((({host:key.str("0")})))))))))',true),
			array('((1 - 1-2-((((((({host:key.str("0")})))))))))',true),
			array('(--(1 - 1-2-((((((({host:key.str("0")})))))))))',false),
			array('(+(1 - 1-2-((((((({host:key.str("0")})))))))))',false),
			array('(/(1 - 1-2-((((((({host:key.str("0")})))))))))',false),
			array('(1 - 1-2-((((((({host:key.str("0")}))))))))/(1 - 1-2-((((((({host:key.str("0")}))))))))',true),
			array('(1 - 1-2-((((((({host:key.str("0")}))))))))-(1 - 1-2-((((((({host:key.str("0")}))))))))',true),
			array('(1 - 1-2-((((((({host:key.str("0")}))))))))+(1 - 1-2-((((((({host:key.str("0")}))))))))',true),
			array('(1 - 1-2-((((((({host:key.str("0")}))))))))|(1 - 1-2-((((((({host:key.str("0")}))))))))',true),
			array('(1 - 1-2-((((((({host:key.str("0")}))))))))&(1 - 1-2-((((((({host:key.str("0")}))))))))',true),
			array('(1 - 1-2-((((((({host:key.str("0")}))))))))&(1 - 1-2-((((((({host:key.str("0")}))))))))/(1 - 1-2-((((((({host:key.str("0")}))))))))',true),
			array('(1 - 1-2-((((((({host:key.str("0")}))))))))+(1 - 1-2-((((((({host:key.str("0")}))))))))/(1 - 1-2-((((((({host:key.str("0")}))))))))',true),
			array('1 - (1/(1 - 1-2-((((((({host:key.str("0")})))))))))+((1 - 1-2-((((((({host:key.str("0")})))))))))/(1 - 1-2-((((((({host:key.str("0")}))))))))/(1 - 1-2-((((((({host:key.str("0")}))))))))',true),
	// by Aleksandrs (July 19, 2011; test cases for ZBX-3911)
			array('{host:log[/data/logs/test.log,incorrect:FAIL].last(0)}', true),
			array('{host:log[/data/logs/test.log,incorrect^FAIL].last(0)}', true),
			array('{host:log[/data/logs/test.log,incorrect/FAIL].last(0)}', true),
			array('{host:log[/data/logs/test.log,incorrect*FAIL].last(0)}', true),
			array('{host:log[/data/logs/test.log,incorrect+FAIL].last(0)}', true),
			array('{host:log[/data/logs/test.log,incorrect-FAIL].last(0)}', true),
			array('{host:log[/data/logs/test.log,incorrect&FAIL].last(0)}', true),
			array('{host:log[/data/logs/test.log,incorrect|FAIL].last(0)}', true),
			array('{host:log[/data/logs/test.log,(incorrect|FAIL].last(0)}', true),
			array('{host:log[/data/logs/test.log,incorrect|FAIL)].last(0)}', true),
			array('{host:log[/data/logs/test.log,(incorrect|FAIL)].last(0)}', true),
			array('{host:log[/data/logs/test.log,{incorrect|FAIL].last(0)}', true),
			array('{host:log[/data/logs/test.log,incorrect|FAIL}].last(0)}', true),
			array('{host:log[/data/logs/test.log,{incorrect|FAIL}].last(0)}', true),
			array('{host:log[/data/logs/test.log,text1(incorrect|FAILtext2].last(0)}', true),
			array('{host:log[/data/logs/test.log,text1incorrect|FAIL)text2].last(0)}', true),
			array('{host:log[/data/logs/test.log,text1(incorrect|FAIL)text2].last(0)}', true),
			array('{Template_App_CCWS:web.page.regexp[0.0.0.0,/ws-callcontrol-1.1/test,{$CCWS_PORT},"[Ss]moke [Tt]est = ([Ss]uccess|[Ww]arning|[Ff]ail).*([[:space:]].*)+"].count(#1,event service = failed)}=1', true),
		);
	}

	/**
	* @dataProvider provider
	*/
	public function test_parse($a, $b) {
		$trigger = new CTriggerExpression(array('expression' => $a));
		if (empty($trigger->errors)) {
			$this->assertEquals($b, true);
		}
		else {
//			print_r($trigger->errors);
			$this->assertEquals($b, false, "\nError with expression $a: ".$trigger->errors[0]);
		}
	}
}
?>
